Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3024)

Unified Diff: firmware/lib/include/vboot_common.h

Issue 3027009: Added size param to VerifyData() (Closed) Base URL: ssh://gitrw.chromium.org/vboot_reference.git
Patch Set: Created 10 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | firmware/lib/vboot_common.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: firmware/lib/include/vboot_common.h
diff --git a/firmware/lib/include/vboot_common.h b/firmware/lib/include/vboot_common.h
index b7998a7ae5b95b3d513cb277751eb09b40f67744..74d85800b86084482db7e7f9f293f317bb8a078c 100644
--- a/firmware/lib/include/vboot_common.h
+++ b/firmware/lib/include/vboot_common.h
@@ -70,8 +70,10 @@ int PublicKeyCopy(VbPublicKey* dest, const VbPublicKey* src);
RSAPublicKey* PublicKeyToRSA(const VbPublicKey* key);
-/* Verifies [data] matches signature [sig] using [key]. */
-int VerifyData(const uint8_t* data, const VbSignature* sig,
+/* Verifies [data] matches signature [sig] using [key]. [size] is the size
+ * of the data buffer; the amount of data to be validated is contained in
+ * sig->data_size. */
+int VerifyData(const uint8_t* data, uint64_t size, const VbSignature* sig,
const RSAPublicKey* key);
@@ -93,7 +95,7 @@ int KeyBlockVerify(const VbKeyBlockHeader* block, uint64_t size,
* using public key [key].
*
* Returns VBOOT_SUCCESS if successful. */
-int VerifyFirmwarePreamble2(const VbFirmwarePreambleHeader* preamble,
+int VerifyFirmwarePreamble(const VbFirmwarePreambleHeader* preamble,
uint64_t size, const RSAPublicKey* key);
@@ -101,7 +103,7 @@ int VerifyFirmwarePreamble2(const VbFirmwarePreambleHeader* preamble,
* using public key [key].
*
* Returns VBOOT_SUCCESS if successful. */
-int VerifyKernelPreamble2(const VbKernelPreambleHeader* preamble,
+int VerifyKernelPreamble(const VbKernelPreambleHeader* preamble,
uint64_t size, const RSAPublicKey* key);
« no previous file with comments | « no previous file | firmware/lib/vboot_common.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698